@@ -250,6 +250,14 @@ do { \
 #define SUPPORTED_Asym_Pause  (1 << 14)
 #endif
 
+#ifndef  MDIO_EEE_100TX
+#define  MDIO_EEE_100TX  0x0002
+#endif
+
+#ifndef  MDIO_EEE_1000T
+#define  MDIO_EEE_1000T  0x0004
+#endif
+
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,29)
 #ifdef CONFIG_NET_POLL_CONTROLLER
 #define RTL_NET_POLL_CONTROLLER dev->poll_controller=rtl8168_netpoll
@@ -327,7 +335,7 @@ do { \
 #define DASH_SUFFIX ""
 #endif
 
-#define RTL8168_VERSION "8.047.02" NAPI_SUFFIX FIBER_SUFFIX REALWOW_SUFFIX DASH_SUFFIX
+#define RTL8168_VERSION "8.048.00" NAPI_SUFFIX FIBER_SUFFIX REALWOW_SUFFIX DASH_SUFFIX
 #define MODULENAME "r8168"
 #define PFX MODULENAME ": "
 
@@ -430,12 +438,12 @@ This is free software, and you are welcome to redistribute it under certain cond
 #define SHORT_PACKET_PADDING_BUF_SIZE 256
 
 /* write/read MMIO register */
-#define RTL_W8(reg, val8)   writeb ((val8), ioaddr + (reg))
-#define RTL_W16(reg, val16) writew ((val16), ioaddr + (reg))
-#define RTL_W32(reg, val32) writel ((val32), ioaddr + (reg))
-#define RTL_R8(reg)     readb (ioaddr + (reg))
-#define RTL_R16(reg)        readw (ioaddr + (reg))
-#define RTL_R32(reg)        ((unsigned long) readl (ioaddr + (reg)))
+#define RTL_W8(tp, reg, val8)	writeb((val8), tp->mmio_addr + (reg))
+#define RTL_W16(tp, reg, val16)	writew((val16), tp->mmio_addr + (reg))
+#define RTL_W32(tp, reg, val32)	writel((val32), tp->mmio_addr + (reg))
+#define RTL_R8(tp, reg)		readb(tp->mmio_addr + (reg))
+#define RTL_R16(tp, reg)		readw(tp->mmio_addr + (reg))
+#define RTL_R32(tp, reg)		((unsigned long) readl(tp->mmio_addr + (reg)))
 
 #ifndef DMA_64BIT_MASK
 #define DMA_64BIT_MASK  0xffffffffffffffffULL
@@ -1564,6 +1572,8 @@ struct rtl8168_private {
         u32 HwFiberStat;
         u8 HwSwitchMdiToFiber;
 
+        u8 HwSuppPhyOcpVer;
+
         u16 NicCustLedValue;
 
         u8 HwSuppMagicPktVer;
@@ -1716,6 +1726,7 @@ enum mcfg {
         CFG_METHOD_30,
         CFG_METHOD_31,
         CFG_METHOD_32,
+        CFG_METHOD_33,
         CFG_METHOD_MAX,
         CFG_METHOD_DEFAULT = 0xFF
 };
@@ -1767,7 +1778,7 @@ void rtl8168_mdio_prot_direct_write_phy_ocp(struct rtl8168_private *tp, u32 RegA
 u32 rtl8168_mdio_read(struct rtl8168_private *tp, u32 RegAddr);
 u32 rtl8168_mdio_prot_read(struct rtl8168_private *tp, u32 RegAddr);
 u32 rtl8168_mdio_prot_direct_read_phy_ocp(struct rtl8168_private *tp, u32 RegAddr);
-void rtl8168_ephy_write(void __iomem *ioaddr, int RegAddr, int value);
+void rtl8168_ephy_write(struct rtl8168_private *tp, int RegAddr, int value);
 void rtl8168_mac_ocp_write(struct rtl8168_private *tp, u16 reg_addr, u16 value);
 u16 rtl8168_mac_ocp_read(struct rtl8168_private *tp, u16 reg_addr);
 void rtl8168_clear_eth_phy_bit(struct rtl8168_private *tp, u8 addr, u16 mask);
@@ -1775,16 +1786,16 @@ void rtl8168_set_eth_phy_bit(struct rtl8168_private *tp,  u8  addr, u16  mask);
 void rtl8168_ocp_write(struct rtl8168_private *tp, u16 addr, u8 len, u32 data);
 void rtl8168_oob_notify(struct rtl8168_private *tp, u8 cmd);
 void rtl8168_init_ring_indexes(struct rtl8168_private *tp);
-int rtl8168_eri_write(void __iomem *ioaddr, int addr, int len, u32 value, int type);
+int rtl8168_eri_write(struct rtl8168_private *tp, int addr, int len, u32 value, int type);
 void rtl8168_oob_mutex_lock(struct rtl8168_private *tp);
 u32 rtl8168_mdio_read(struct rtl8168_private *tp, u32 RegAddr);
 u32 rtl8168_ocp_read(struct rtl8168_private *tp, u16 addr, u8 len);
 u32 rtl8168_ocp_read_with_oob_base_address(struct rtl8168_private *tp, u16 addr, u8 len, u32 base_address);
 u32 rtl8168_ocp_write_with_oob_base_address(struct rtl8168_private *tp, u16 addr, u8 len, u32 value, u32 base_address);
-u32 rtl8168_eri_read(void __iomem *ioaddr, int addr, int len, int type);
-u32 rtl8168_eri_read_with_oob_base_address(void __iomem *ioaddr, int addr, int len, int type, u32 base_address);
-int rtl8168_eri_write_with_oob_base_address(void __iomem *ioaddr, int addr, int len, u32 value, int type, u32 base_address);
-u16 rtl8168_ephy_read(void __iomem *ioaddr, int RegAddr);
+u32 rtl8168_eri_read(struct rtl8168_private *tp, int addr, int len, int type);
+u32 rtl8168_eri_read_with_oob_base_address(struct rtl8168_private *tp, int addr, int len, int type, u32 base_address);
+int rtl8168_eri_write_with_oob_base_address(struct rtl8168_private *tp, int addr, int len, u32 value, int type, u32 base_address);
+u16 rtl8168_ephy_read(struct rtl8168_private *tp, int RegAddr);
 void rtl8168_wait_txrx_fifo_empty(struct net_device *dev);
 void rtl8168_wait_ll_share_fifo_ready(struct net_device *dev);
 void rtl8168_enable_now_is_oob(struct rtl8168_private *tp);
