@@ -4,7 +4,7 @@
 # r8168 is the Linux device driver released for Realtek Gigabit Ethernet
 # controllers with PCI-Express interface.
 #
-# Copyright(c) 2018 Realtek Semiconductor Corp. All rights reserved.
+# Copyright(c) 2019 Realtek Semiconductor Corp. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the Free
@@ -277,18 +277,18 @@ struct asf_ioctl_struct {
 };
 
 int rtl8168_asf_ioctl(struct net_device *dev, struct ifreq *ifr);
-void rtl8168_asf_hbperiod(void __iomem *ioaddr, int arg, unsigned int *data);
-void rtl8168_asf_wd16rst(void __iomem *ioaddr, int arg, unsigned int *data);
+void rtl8168_asf_hbperiod(struct rtl8168_private *tp, int arg, unsigned int *data);
+void rtl8168_asf_wd16rst(struct rtl8168_private *tp, int arg, unsigned int *data);
 void rtl8168_asf_console_mac(struct rtl8168_private *, int arg, unsigned int *data);
 void rtl8168_asf_ip_address(struct rtl8168_private *, int arg, int offset, unsigned int *data);
-void rtl8168_asf_config_regs(void __iomem *ioaddr, int arg, int offset, unsigned int *data);
-void rtl8168_asf_capability_masks(void __iomem *ioaddr, int arg, int offset, unsigned int *data);
-void rtl8168_asf_community_string(void __iomem *ioaddr, int arg, char *string);
-void rtl8168_asf_community_string_len(void __iomem *ioaddr, int arg, unsigned int *data);
-void rtl8168_asf_alert_resend_interval(void __iomem *ioaddr, int arg, unsigned int *data);
-void rtl8168_asf_time_period(void __iomem *ioaddr, int arg, int offset, unsigned int *data);
+void rtl8168_asf_config_regs(struct rtl8168_private *tp, int arg, int offset, unsigned int *data);
+void rtl8168_asf_capability_masks(struct rtl8168_private *tp, int arg, int offset, unsigned int *data);
+void rtl8168_asf_community_string(struct rtl8168_private *tp, int arg, char *string);
+void rtl8168_asf_community_string_len(struct rtl8168_private *tp, int arg, unsigned int *data);
+void rtl8168_asf_alert_resend_interval(struct rtl8168_private *tp, int arg, unsigned int *data);
+void rtl8168_asf_time_period(struct rtl8168_private *tp, int arg, int offset, unsigned int *data);
 void rtl8168_asf_key_access(struct rtl8168_private *, int arg, int offset, unsigned int *data);
-void rtl8168_asf_rw_hexadecimal(void __iomem *ioaddr, int arg, int offset, int len, unsigned int *data);
-void rtl8168_asf_rw_iana(void __iomem *ioaddr, int arg, unsigned int *data);
-void rtl8168_asf_rw_uuid(void __iomem *ioaddr, int arg, unsigned int *data);
-void rtl8168_asf_rw_systemid(void __iomem *ioaddr, int arg, unsigned int *data);
+void rtl8168_asf_rw_hexadecimal(struct rtl8168_private *tp, int arg, int offset, int len, unsigned int *data);
+void rtl8168_asf_rw_iana(struct rtl8168_private *tp, int arg, unsigned int *data);
+void rtl8168_asf_rw_uuid(struct rtl8168_private *tp, int arg, unsigned int *data);
+void rtl8168_asf_rw_systemid(struct rtl8168_private *tp, int arg, unsigned int *data);
