@@ -52,18 +52,17 @@
 //-------------------------------------------------------------------
 void rtl8168_eeprom_type(struct rtl8168_private *tp)
 {
-        void __iomem *ioaddr=tp->mmio_addr;
         u16 magic = 0;
 
         if (tp->mcfg == CFG_METHOD_DEFAULT)
                 goto out_no_eeprom;
 
-        if(RTL_R8(0xD2)&0x04) {
+        if(RTL_R8(tp, 0xD2)&0x04) {
                 //not support
                 //tp->eeprom_type = EEPROM_TWSI;
                 //tp->eeprom_len = 256;
                 goto out_no_eeprom;
-        } else if(RTL_R32(RxConfig) & RxCfg_9356SEL) {
+        } else if(RTL_R32(tp, RxConfig) & RxCfg_9356SEL) {
                 tp->eeprom_type = EEPROM_TYPE_93C56;
                 tp->eeprom_len = 256;
         } else {
@@ -80,28 +79,28 @@ out_no_eeprom:
         }
 }
 
-void rtl8168_eeprom_cleanup(void __iomem *ioaddr)
+void rtl8168_eeprom_cleanup(struct rtl8168_private *tp)
 {
         u8 x;
 
-        x = RTL_R8(Cfg9346);
+        x = RTL_R8(tp, Cfg9346);
         x &= ~(Cfg9346_EEDI | Cfg9346_EECS);
 
-        RTL_W8(Cfg9346, x);
+        RTL_W8(tp, Cfg9346, x);
 
-        rtl8168_raise_clock(&x, ioaddr);
-        rtl8168_lower_clock(&x, ioaddr);
+        rtl8168_raise_clock(tp, &x);
+        rtl8168_lower_clock(tp, &x);
 }
 
-int rtl8168_eeprom_cmd_done(void __iomem *ioaddr)
+int rtl8168_eeprom_cmd_done(struct rtl8168_private *tp)
 {
         u8 x;
         int i;
 
-        rtl8168_stand_by(ioaddr);
+        rtl8168_stand_by(tp);
 
         for (i = 0; i < 50000; i++) {
-                x = RTL_R8(Cfg9346);
+                x = RTL_R8(tp, Cfg9346);
 
                 if (x & Cfg9346_EEDO) {
                         udelay(RTL_CLOCK_RATE * 2 * 3);
@@ -119,7 +118,6 @@ int rtl8168_eeprom_cmd_done(void __iomem *ioaddr)
 //-------------------------------------------------------------------
 u16 rtl8168_eeprom_read_sc(struct rtl8168_private *tp, u16 reg)
 {
-        void __iomem *ioaddr=tp->mmio_addr;
         int addr_sz = 6;
         u8 x;
         u16 data;
@@ -134,16 +132,16 @@ u16 rtl8168_eeprom_read_sc(struct rtl8168_private *tp, u16 reg)
                 addr_sz = 8;
 
         x = Cfg9346_EEM1 | Cfg9346_EECS;
-        RTL_W8(Cfg9346, x);
+        RTL_W8(tp, Cfg9346, x);
 
-        rtl8168_shift_out_bits(RTL_EEPROM_READ_OPCODE, 3, ioaddr);
-        rtl8168_shift_out_bits(reg, addr_sz, ioaddr);
+        rtl8168_shift_out_bits(tp, RTL_EEPROM_READ_OPCODE, 3);
+        rtl8168_shift_out_bits(tp, reg, addr_sz);
 
-        data = rtl8168_shift_in_bits(ioaddr);
+        data = rtl8168_shift_in_bits(tp);
 
-        rtl8168_eeprom_cleanup(ioaddr);
+        rtl8168_eeprom_cleanup(tp);
 
-        RTL_W8(Cfg9346, 0);
+        RTL_W8(tp, Cfg9346, 0);
 
         return data;
 }
@@ -154,7 +152,6 @@ u16 rtl8168_eeprom_read_sc(struct rtl8168_private *tp, u16 reg)
 //-------------------------------------------------------------------
 void rtl8168_eeprom_write_sc(struct rtl8168_private *tp, u16 reg, u16 data)
 {
-        void __iomem *ioaddr=tp->mmio_addr;
         u8 x;
         int addr_sz = 6;
         int w_dummy_addr = 4;
@@ -172,56 +169,56 @@ void rtl8168_eeprom_write_sc(struct rtl8168_private *tp, u16 reg, u16 data)
         }
 
         x = Cfg9346_EEM1 | Cfg9346_EECS;
-        RTL_W8(Cfg9346, x);
+        RTL_W8(tp, Cfg9346, x);
 
-        rtl8168_shift_out_bits(RTL_EEPROM_EWEN_OPCODE, 5, ioaddr);
-        rtl8168_shift_out_bits(reg, w_dummy_addr, ioaddr);
-        rtl8168_stand_by(ioaddr);
+        rtl8168_shift_out_bits(tp, RTL_EEPROM_EWEN_OPCODE, 5);
+        rtl8168_shift_out_bits(tp, reg, w_dummy_addr);
+        rtl8168_stand_by(tp);
 
-        rtl8168_shift_out_bits(RTL_EEPROM_ERASE_OPCODE, 3, ioaddr);
-        rtl8168_shift_out_bits(reg, addr_sz, ioaddr);
-        if (rtl8168_eeprom_cmd_done(ioaddr) < 0) {
+        rtl8168_shift_out_bits(tp, RTL_EEPROM_ERASE_OPCODE, 3);
+        rtl8168_shift_out_bits(tp, reg, addr_sz);
+        if (rtl8168_eeprom_cmd_done(tp) < 0) {
                 return;
         }
-        rtl8168_stand_by(ioaddr);
+        rtl8168_stand_by(tp);
 
-        rtl8168_shift_out_bits(RTL_EEPROM_WRITE_OPCODE, 3, ioaddr);
-        rtl8168_shift_out_bits(reg, addr_sz, ioaddr);
-        rtl8168_shift_out_bits(data, 16, ioaddr);
-        if (rtl8168_eeprom_cmd_done(ioaddr) < 0) {
+        rtl8168_shift_out_bits(tp, RTL_EEPROM_WRITE_OPCODE, 3);
+        rtl8168_shift_out_bits(tp, reg, addr_sz);
+        rtl8168_shift_out_bits(tp, data, 16);
+        if (rtl8168_eeprom_cmd_done(tp) < 0) {
                 return;
         }
-        rtl8168_stand_by(ioaddr);
+        rtl8168_stand_by(tp);
 
-        rtl8168_shift_out_bits(RTL_EEPROM_EWDS_OPCODE, 5, ioaddr);
-        rtl8168_shift_out_bits(reg, w_dummy_addr, ioaddr);
+        rtl8168_shift_out_bits(tp, RTL_EEPROM_EWDS_OPCODE, 5);
+        rtl8168_shift_out_bits(tp, reg, w_dummy_addr);
 
-        rtl8168_eeprom_cleanup(ioaddr);
-        RTL_W8(Cfg9346, 0);
+        rtl8168_eeprom_cleanup(tp);
+        RTL_W8(tp, Cfg9346, 0);
 }
 
-void rtl8168_raise_clock(u8 *x, void __iomem *ioaddr)
+void rtl8168_raise_clock(struct rtl8168_private *tp, u8 *x)
 {
         *x = *x | Cfg9346_EESK;
-        RTL_W8(Cfg9346, *x);
+        RTL_W8(tp, Cfg9346, *x);
         udelay(RTL_CLOCK_RATE);
 }
 
-void rtl8168_lower_clock(u8 *x, void __iomem *ioaddr)
+void rtl8168_lower_clock(struct rtl8168_private *tp, u8 *x)
 {
 
         *x = *x & ~Cfg9346_EESK;
-        RTL_W8(Cfg9346, *x);
+        RTL_W8(tp, Cfg9346, *x);
         udelay(RTL_CLOCK_RATE);
 }
 
-void rtl8168_shift_out_bits(int data, int count, void __iomem *ioaddr)
+void rtl8168_shift_out_bits(struct rtl8168_private *tp, int data, int count)
 {
         u8 x;
         int  mask;
 
         mask = 0x01 << (count - 1);
-        x = RTL_R8(Cfg9346);
+        x = RTL_R8(tp, Cfg9346);
         x &= ~(Cfg9346_EEDI | Cfg9346_EEDO);
 
         do {
@@ -230,62 +227,62 @@ void rtl8168_shift_out_bits(int data, int count, void __iomem *ioaddr)
                 else
                         x &= ~Cfg9346_EEDI;
 
-                RTL_W8(Cfg9346, x);
+                RTL_W8(tp, Cfg9346, x);
                 udelay(RTL_CLOCK_RATE);
-                rtl8168_raise_clock(&x, ioaddr);
-                rtl8168_lower_clock(&x, ioaddr);
+                rtl8168_raise_clock(tp, &x);
+                rtl8168_lower_clock(tp, &x);
                 mask = mask >> 1;
         } while(mask);
 
         x &= ~Cfg9346_EEDI;
-        RTL_W8(Cfg9346, x);
+        RTL_W8(tp, Cfg9346, x);
 }
 
-u16 rtl8168_shift_in_bits(void __iomem *ioaddr)
+u16 rtl8168_shift_in_bits(struct rtl8168_private *tp)
 {
         u8 x;
         u16 d, i;
 
-        x = RTL_R8(Cfg9346);
+        x = RTL_R8(tp, Cfg9346);
         x &= ~(Cfg9346_EEDI | Cfg9346_EEDO);
 
         d = 0;
 
         for (i = 0; i < 16; i++) {
                 d = d << 1;
-                rtl8168_raise_clock(&x, ioaddr);
+                rtl8168_raise_clock(tp, &x);
 
-                x = RTL_R8(Cfg9346);
+                x = RTL_R8(tp, Cfg9346);
                 x &= ~Cfg9346_EEDI;
 
                 if (x & Cfg9346_EEDO)
                         d |= 1;
 
-                rtl8168_lower_clock(&x, ioaddr);
+                rtl8168_lower_clock(tp, &x);
         }
 
         return d;
 }
 
-void rtl8168_stand_by(void __iomem *ioaddr)
+void rtl8168_stand_by(struct rtl8168_private *tp)
 {
         u8 x;
 
-        x = RTL_R8(Cfg9346);
+        x = RTL_R8(tp, Cfg9346);
         x &= ~(Cfg9346_EECS | Cfg9346_EESK);
-        RTL_W8(Cfg9346, x);
+        RTL_W8(tp, Cfg9346, x);
         udelay(RTL_CLOCK_RATE);
 
         x |= Cfg9346_EECS;
-        RTL_W8(Cfg9346, x);
+        RTL_W8(tp, Cfg9346, x);
 }
 
-void rtl8168_set_eeprom_sel_low(void __iomem *ioaddr)
+void rtl8168_set_eeprom_sel_low(struct rtl8168_private *tp)
 {
-        RTL_W8(Cfg9346, Cfg9346_EEM1);
-        RTL_W8(Cfg9346, Cfg9346_EEM1 | Cfg9346_EESK);
+        RTL_W8(tp, Cfg9346, Cfg9346_EEM1);
+        RTL_W8(tp, Cfg9346, Cfg9346_EEM1 | Cfg9346_EESK);
 
         udelay(20);
 
-        RTL_W8(Cfg9346, Cfg9346_EEM1);
+        RTL_W8(tp, Cfg9346, Cfg9346_EEM1);
 }
