@@ -1,3 +1,36 @@
+/*
+################################################################################
+#
+# r8168 is the Linux device driver released for Realtek Gigabit Ethernet
+# controllers with PCI-Express interface.
+#
+# Copyright(c) 2019 Realtek Semiconductor Corp. All rights reserved.
+#
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License as published by the Free
+# Software Foundation; either version 2 of the License, or (at your option)
+# any later version.
+#
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+# more details.
+#
+# You should have received a copy of the GNU General Public License along with
+# this program; if not, see <http://www.gnu.org/licenses/>.
+#
+# Author:
+# Realtek NIC software team <nicfae@realtek.com>
+# No. 2, Innovation Road II, Hsinchu Science Park, Hsinchu 300, Taiwan
+#
+################################################################################
+*/
+
+/************************************************************************************
+ *  This product is covered by one or more of the following patents:
+ *  US6,570,884, US6,115,776, and US6,327,625.
+ ***********************************************************************************/
+
 #include <linux/module.h>
 #include <linux/version.h>
 #include <linux/pci.h>
@@ -10,10 +43,10 @@
 #include "rtl_eeprom.h"
 #include "rtltool.h"
 
-int rtltool_ioctl(struct rtl8168_private *tp, struct ifreq *ifr)
+int rtl8168_tool_ioctl(struct rtl8168_private *tp, struct ifreq *ifr)
 {
         struct rtltool_cmd my_cmd;
-        unsigned long flags, flags2;
+        unsigned long flags;
         int ret;
 
         if (copy_from_user(&my_cmd, ifr->ifr_data, sizeof(my_cmd)))
@@ -63,9 +96,9 @@ int rtltool_ioctl(struct rtl8168_private *tp, struct ifreq *ifr)
                 if (!capable(CAP_NET_ADMIN))
                         return -EPERM;
 
-                spin_lock_irqsave(&tp->phy_lock, flags);
-                my_cmd.data = mdio_read(tp, my_cmd.offset);
-                spin_unlock_irqrestore(&tp->phy_lock, flags);
+                spin_lock_irqsave(&tp->lock, flags);
+                my_cmd.data = rtl8168_mdio_prot_read(tp, my_cmd.offset);
+                spin_unlock_irqrestore(&tp->lock, flags);
 
                 if (copy_to_user(ifr->ifr_data, &my_cmd, sizeof(my_cmd))) {
                         ret = -EFAULT;
@@ -78,18 +111,18 @@ int rtltool_ioctl(struct rtl8168_private *tp, struct ifreq *ifr)
                 if (!capable(CAP_NET_ADMIN))
                         return -EPERM;
 
-                spin_lock_irqsave(&tp->phy_lock, flags);
-                mdio_prot_write(tp, my_cmd.offset, my_cmd.data);
-                spin_unlock_irqrestore(&tp->phy_lock, flags);
+                spin_lock_irqsave(&tp->lock, flags);
+                rtl8168_mdio_prot_write(tp, my_cmd.offset, my_cmd.data);
+                spin_unlock_irqrestore(&tp->lock, flags);
                 break;
 
         case RTLTOOL_READ_EPHY:
                 if (!capable(CAP_NET_ADMIN))
                         return -EPERM;
 
-                spin_lock_irqsave(&tp->phy_lock, flags);
-                my_cmd.data = rtl8168_ephy_read(tp->mmio_addr, my_cmd.offset);
-                spin_unlock_irqrestore(&tp->phy_lock, flags);
+                spin_lock_irqsave(&tp->lock, flags);
+                my_cmd.data = rtl8168_ephy_read(tp, my_cmd.offset);
+                spin_unlock_irqrestore(&tp->lock, flags);
 
                 if (copy_to_user(ifr->ifr_data, &my_cmd, sizeof(my_cmd))) {
                         ret = -EFAULT;
@@ -102,17 +135,17 @@ int rtltool_ioctl(struct rtl8168_private *tp, struct ifreq *ifr)
                 if (!capable(CAP_NET_ADMIN))
                         return -EPERM;
 
-                spin_lock_irqsave(&tp->phy_lock, flags);
-                rtl8168_ephy_write(tp->mmio_addr, my_cmd.offset, my_cmd.data);
-                spin_unlock_irqrestore(&tp->phy_lock, flags);
+                spin_lock_irqsave(&tp->lock, flags);
+                rtl8168_ephy_write(tp, my_cmd.offset, my_cmd.data);
+                spin_unlock_irqrestore(&tp->lock, flags);
                 break;
 
         case RTLTOOL_READ_ERI:
                 my_cmd.data = 0;
                 if (my_cmd.len==1 || my_cmd.len==2 || my_cmd.len==4) {
-                        spin_lock_irqsave(&tp->phy_lock, flags);
-                        my_cmd.data = rtl8168_eri_read(tp->mmio_addr, my_cmd.offset, my_cmd.len, ERIAR_ExGMAC);
-                        spin_unlock_irqrestore(&tp->phy_lock, flags);
+                        spin_lock_irqsave(&tp->lock, flags);
+                        my_cmd.data = rtl8168_eri_read(tp, my_cmd.offset, my_cmd.len, ERIAR_ExGMAC);
+                        spin_unlock_irqrestore(&tp->lock, flags);
                 } else {
                         ret = -EOPNOTSUPP;
                         break;
@@ -133,9 +166,9 @@ int rtltool_ioctl(struct rtl8168_private *tp, struct ifreq *ifr)
                         return -EPERM;
 
                 if (my_cmd.len==1 || my_cmd.len==2 || my_cmd.len==4) {
-                        spin_lock_irqsave(&tp->phy_lock, flags);
-                        rtl8168_eri_write(tp->mmio_addr, my_cmd.offset, my_cmd.len, my_cmd.data, ERIAR_ExGMAC);
-                        spin_unlock_irqrestore(&tp->phy_lock, flags);
+                        spin_lock_irqsave(&tp->lock, flags);
+                        rtl8168_eri_write(tp, my_cmd.offset, my_cmd.len, my_cmd.data, ERIAR_ExGMAC);
+                        spin_unlock_irqrestore(&tp->lock, flags);
                 } else {
                         ret = -EOPNOTSUPP;
                         break;
@@ -191,9 +224,9 @@ int rtltool_ioctl(struct rtl8168_private *tp, struct ifreq *ifr)
                 if (!capable(CAP_NET_ADMIN))
                         return -EPERM;
 
-                spin_lock_irqsave(&tp->phy_lock, flags);
-                my_cmd.data = rtl_eeprom_read_sc(tp, my_cmd.offset);
-                spin_unlock_irqrestore(&tp->phy_lock, flags);
+                spin_lock_irqsave(&tp->lock, flags);
+                my_cmd.data = rtl8168_eeprom_read_sc(tp, my_cmd.offset);
+                spin_unlock_irqrestore(&tp->lock, flags);
 
                 if (copy_to_user(ifr->ifr_data, &my_cmd, sizeof(my_cmd))) {
                         ret = -EFAULT;
@@ -206,20 +239,20 @@ int rtltool_ioctl(struct rtl8168_private *tp, struct ifreq *ifr)
                 if (!capable(CAP_NET_ADMIN))
                         return -EPERM;
 
-                spin_lock_irqsave(&tp->phy_lock, flags);
-                rtl_eeprom_write_sc(tp, my_cmd.offset, my_cmd.data);
-                spin_unlock_irqrestore(&tp->phy_lock, flags);
+                spin_lock_irqsave(&tp->lock, flags);
+                rtl8168_eeprom_write_sc(tp, my_cmd.offset, my_cmd.data);
+                spin_unlock_irqrestore(&tp->lock, flags);
                 break;
 
         case RTL_READ_OOB_MAC:
                 if (!capable(CAP_NET_ADMIN))
                         return -EPERM;
 
-                spin_lock_irqsave(&tp->phy_lock, flags);
-                OOB_mutex_lock(tp);
-                my_cmd.data = OCP_read(tp, my_cmd.offset, 4);
-                OOB_mutex_unlock(tp);
-                spin_unlock_irqrestore(&tp->phy_lock, flags);
+                spin_lock_irqsave(&tp->lock, flags);
+                rtl8168_oob_mutex_lock(tp);
+                my_cmd.data = rtl8168_ocp_read(tp, my_cmd.offset, 4);
+                rtl8168_oob_mutex_unlock(tp);
+                spin_unlock_irqrestore(&tp->lock, flags);
 
                 if (copy_to_user(ifr->ifr_data, &my_cmd, sizeof(my_cmd))) {
                         ret = -EFAULT;
@@ -234,11 +267,11 @@ int rtltool_ioctl(struct rtl8168_private *tp, struct ifreq *ifr)
                 if (my_cmd.len == 0 || my_cmd.len > 4)
                         return -EOPNOTSUPP;
 
-                spin_lock_irqsave(&tp->phy_lock, flags);
-                OOB_mutex_lock(tp);
-                OCP_write(tp, my_cmd.offset, my_cmd.len, my_cmd.data);
-                OOB_mutex_unlock(tp);
-                spin_unlock_irqrestore(&tp->phy_lock, flags);
+                spin_lock_irqsave(&tp->lock, flags);
+                rtl8168_oob_mutex_lock(tp);
+                rtl8168_ocp_write(tp, my_cmd.offset, my_cmd.len, my_cmd.data);
+                rtl8168_oob_mutex_unlock(tp);
+                spin_unlock_irqrestore(&tp->lock, flags);
                 break;
 
         case RTL_ENABLE_PCI_DIAG:
@@ -246,9 +279,7 @@ int rtltool_ioctl(struct rtl8168_private *tp, struct ifreq *ifr)
                         return -EPERM;
 
                 spin_lock_irqsave(&tp->lock, flags);
-                spin_lock_irqsave(&tp->phy_lock, flags2);
                 tp->rtk_enable_diag = 1;
-                spin_unlock_irqrestore(&tp->phy_lock, flags2);
                 spin_unlock_irqrestore(&tp->lock, flags);
 
                 dprintk("enable rtk diag\n");
@@ -259,9 +290,7 @@ int rtltool_ioctl(struct rtl8168_private *tp, struct ifreq *ifr)
                         return -EPERM;
 
                 spin_lock_irqsave(&tp->lock, flags);
-                spin_lock_irqsave(&tp->phy_lock, flags2);
                 tp->rtk_enable_diag = 0;
-                spin_unlock_irqrestore(&tp->phy_lock, flags2);
                 spin_unlock_irqrestore(&tp->lock, flags);
 
                 dprintk("disable rtk diag\n");
@@ -274,9 +303,9 @@ int rtltool_ioctl(struct rtl8168_private *tp, struct ifreq *ifr)
                 if (my_cmd.offset % 2)
                         return -EOPNOTSUPP;
 
-                spin_lock_irqsave(&tp->phy_lock, flags);
-                my_cmd.data = mac_ocp_read(tp, my_cmd.offset);
-                spin_unlock_irqrestore(&tp->phy_lock, flags);
+                spin_lock_irqsave(&tp->lock, flags);
+                my_cmd.data = rtl8168_mac_ocp_read(tp, my_cmd.offset);
+                spin_unlock_irqrestore(&tp->lock, flags);
 
                 if (copy_to_user(ifr->ifr_data, &my_cmd, sizeof(my_cmd))) {
                         ret = -EFAULT;
@@ -291,9 +320,33 @@ int rtltool_ioctl(struct rtl8168_private *tp, struct ifreq *ifr)
                 if ((my_cmd.offset % 2) || (my_cmd.len != 2))
                         return -EOPNOTSUPP;
 
-                spin_lock_irqsave(&tp->phy_lock, flags);
-                mac_ocp_write(tp, my_cmd.offset, (u16)my_cmd.data);
-                spin_unlock_irqrestore(&tp->phy_lock, flags);
+                spin_lock_irqsave(&tp->lock, flags);
+                rtl8168_mac_ocp_write(tp, my_cmd.offset, (u16)my_cmd.data);
+                spin_unlock_irqrestore(&tp->lock, flags);
+                break;
+
+        case RTL_DIRECT_READ_PHY_OCP:
+                if (!capable(CAP_NET_ADMIN))
+                        return -EPERM;
+
+                spin_lock_irqsave(&tp->lock, flags);
+                my_cmd.data = rtl8168_mdio_prot_direct_read_phy_ocp(tp, my_cmd.offset);
+                spin_unlock_irqrestore(&tp->lock, flags);
+
+                if (copy_to_user(ifr->ifr_data, &my_cmd, sizeof(my_cmd))) {
+                        ret = -EFAULT;
+                        break;
+                }
+
+                break;
+
+        case RTL_DIRECT_WRITE_PHY_OCP:
+                if (!capable(CAP_NET_ADMIN))
+                        return -EPERM;
+
+                spin_lock_irqsave(&tp->lock, flags);
+                rtl8168_mdio_prot_direct_write_phy_ocp(tp, my_cmd.offset, my_cmd.data);
+                spin_unlock_irqrestore(&tp->lock, flags);
                 break;
 
         default:
